@@ -36,7 +36,7 @@
 //! ```
 
 #![no_std]
-#![doc(html_root_url = "https://docs.rs/bit-iter/0.1.6")]
+#![doc(html_root_url = "https://docs.rs/bit-iter/1.0.0")]
 
 use core::{iter::FusedIterator, mem::size_of};
 
@@ -73,7 +73,7 @@ mod tests;
 /// let v : Vec<usize> = BitIter::from(0b10000001).rev().collect();
 /// assert_eq!(v, vec![7, 0]);
 /// ```
-#[derive(Debug)]
+#[derive(Clone, Copy, Debug, Default, Eq, Hash, PartialEq)]
 pub struct BitIter<T>(T);
 
 macro_rules! iter_impl {
@@ -132,6 +132,19 @@ macro_rules! iter_impl {
                 self.next()
             }
 
+            #[inline]
+            fn fold<B, F>(mut self, init: B, mut f: F) -> B
+            where
+                F: FnMut(B, Self::Item) -> B
+            {
+                let mut accum = init;
+                while self.0 != 0 {
+                    accum = f(accum, self.0.trailing_zeros() as usize);
+                    self.0 &= self.0.wrapping_sub(1);
+                }
+                accum
+            }
+
             #[inline]
             fn max(self) -> Option<Self::Item> {
                 self.last()
